@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2007  NTT DATA CORPORATION
  *
- * Version: 1.4   2007/04/01
+ * Version: 1.5.0   2007/09/20
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -19,20 +19,20 @@
 
 /***** The structure for reserved ports. *****/
 
-typedef struct reserved_entry {
+struct reserved_entry {
 	struct reserved_entry *next; /* Pointer to next record. NULL if none. */
 	int is_deleted;              /* Delete flag.                          */
 	u16 min_port;                /* Start of port number range.           */
 	u16 max_port;                /* End of port number range.             */
-} RESERVED_ENTRY;
+};
 
 /*************************  NETWORK RESERVED ACL HANDLER  *************************/
 
-static RESERVED_ENTRY *reservedport_list = NULL;
+static struct reserved_entry *reservedport_list = NULL;
 
 static int AddReservedEntry(const u16 min_port, const u16 max_port, const int is_delete)
 {
-	RESERVED_ENTRY *new_entry, *ptr;
+	struct reserved_entry *new_entry, *ptr;
 	static DECLARE_MUTEX(lock);
 	int error = -ENOMEM;
 	for (ptr = reservedport_list; ptr; ptr = ptr->next) {
@@ -45,7 +45,7 @@ static int AddReservedEntry(const u16 min_port, const u16 max_port, const int is
 		error = -ENOENT;
 		goto out;
 	}
-	if ((new_entry = (RESERVED_ENTRY *) alloc_element(sizeof(RESERVED_ENTRY))) == NULL) goto out;
+	if ((new_entry = alloc_element(sizeof(*new_entry))) == NULL) goto out;
 	new_entry->min_port = min_port;
 	new_entry->max_port = max_port;
 	mb(); /* Instead of using spinlock. */
@@ -63,13 +63,14 @@ static int AddReservedEntry(const u16 min_port, const u16 max_port, const int is
 int SAKURA_MayAutobind(const u16 port)
 {
 	/* Must not sleep, for called inside spin_lock. */
-	RESERVED_ENTRY *ptr;
+	struct reserved_entry *ptr;
 	if (!CheckCCSFlags(CCS_SAKURA_RESTRICT_AUTOBIND)) return 0;
 	for (ptr = reservedport_list; ptr; ptr = ptr->next) {
 		if (ptr->min_port <= port && port <= ptr->max_port && !ptr->is_deleted) return -EPERM;
 	}
 	return 0;
 }
+EXPORT_SYMBOL(SAKURA_MayAutobind);
 
 int AddReservedPortPolicy(char *data, const int is_delete)
 {
@@ -85,12 +86,12 @@ int AddReservedPortPolicy(char *data, const int is_delete)
 	return -EINVAL;
 }
 
-int ReadReservedPortPolicy(IO_BUFFER *head)
+int ReadReservedPortPolicy(struct io_buffer *head)
 {
-	RESERVED_ENTRY *ptr = (RESERVED_ENTRY *) head->read_var2;
+	struct reserved_entry *ptr = head->read_var2;
 	if (!ptr) ptr = reservedport_list;
 	while (ptr) {
-		head->read_var2 = (void *) ptr;
+		head->read_var2 = ptr;
 		if (!ptr->is_deleted) {
 			if (ptr->min_port != ptr->max_port) {
 				if (io_printf(head, KEYWORD_DENY_AUTOBIND "%u-%u\n", ptr->min_port, ptr->max_port)) break;
@@ -103,6 +104,4 @@ int ReadReservedPortPolicy(IO_BUFFER *head)
 	return ptr ? -ENOMEM : 0;
 }
 
-EXPORT_SYMBOL(SAKURA_MayAutobind);
-
 /***** SAKURA Linux end. *****/
